@@ -13,9 +13,13 @@ class PlumedLexer(RegexLexer):
             # Deals with all comments
             (r'#.*?$', Comment),
             # Deals with incomplete inputs 
+            (r'(__FILL__)(=)(\S+\b)', bygroups(Literal, Text, Generic)),
+            (r'(\w+)(=)(__FILL__)', bygroups(Name.Attribute, Text, Literal)),
             (r'__FILL__', Literal),  
             # Find LABEL=lab
             (r'((?i)LABEL)(=)(\S+\b)', bygroups(Name.Attribute, Text, String.Double)),
+            # Find special replica syntax with fill
+            (r'(\w+)(=)(@replicas:)(__FILL__)', bygroups(Name.Attribute, Text, Name.Constant, Literal)), 
             # Find special replica syntax with brackets
             (r'(\w+)(=)(@replicas:)((?s)\{.*?\})', bygroups(Name.Attribute, Text, Name.Constant, Generic)),  
             # Find special replica syntax without brackets
@@ -50,6 +54,8 @@ class PlumedLexer(RegexLexer):
             (r'#\s*vim:\s*ft=plumed',Literal),
             # Include all the default stuff
             include('defaults'), 
+            # Find label: __FILL__
+            (r'(.+)(:\s+)(__FILL__)', bygroups(String, Text, Literal)),
             # Find label: ACTION
             (r'(.+)(:\s+)(\S+\b)', bygroups(String, Text, Keyword)),
             # Find label: ... \n ACTION  
